# Auto Image Augment

## Introduction

Implementation of AutoAugment system.


Paper [AutoAugment: Learning Augmentation Policies from Data](https://arxiv.org/pdf/1805.09501.pdf).

Base on [imgaug](https://github.com/aleju/imgaug). 
